@@ -75,6 +75,8 @@ class _CreateCategoricalEncodedVariables(DoFn):
 
     def process(self, df):
 
+        from feature_creation_utils.feature_creation_utils import LabelEncoderExt
+
         # Multi Label Binarizer Variables
         # Split out Equipment Types
 
@@ -193,7 +195,7 @@ class _CreateLoadQuantiles(DoFn):
         super(_CreateLoadQuantiles, self).__init__()
 
     def process(self, data):
-
+        from load_features_utils.feature_creation_utils import LabelEncoderExt
         # Put into dataframe
         df = pd.DataFrame(list(data))
         load_quantile_df = get_load_quantiles()
